==> open-cluster-management-policy-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicyBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PolicyBuilder extends io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluentImpl<io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy,io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyBuilder>{
  public PolicyBuilder() {
    this(false);
  }
  public PolicyBuilder(java.lang.Boolean validationEnabled) {
    this(new Policy(), validationEnabled);
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Policy(), validationEnabled);
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluent<?> fluent,io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy instance) {
    this(fluent, instance, false);
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluent<?> fluent,io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy instance) {
    this(instance,false);
  }
  public PolicyBuilder(io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.PolicyFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1.Policy build() {
    Policy buildable = new Policy(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PolicyBuilder that = (PolicyBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-policy-model-6.1.0-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/PolicyBuilder.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PolicyBuilder extends PolicyFluentImpl<PolicyBuilder> implements VisitableBuilder<Policy,PolicyBuilder>{
  public PolicyBuilder() {
    this(false);
  }
  public PolicyBuilder(Boolean validationEnabled) {
    this(new Policy(), validationEnabled);
  }
  public PolicyBuilder(PolicyFluent<?> fluent) {
    this(fluent, false);
  }
  public PolicyBuilder(PolicyFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Policy(), validationEnabled);
  }
  public PolicyBuilder(PolicyFluent<?> fluent,Policy instance) {
    this(fluent, instance, false);
  }
  public PolicyBuilder(PolicyFluent<?> fluent,Policy instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public PolicyBuilder(Policy instance) {
    this(instance,false);
  }
  public PolicyBuilder(Policy instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  PolicyFluent<?> fluent;
  Boolean validationEnabled;
  public Policy build() {
    Policy buildable = new Policy(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  
}
